#
# spec file for package picotool
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sdk_version 2.1.1
Name:           picotool
Version:        2.1.1
Release:        1.1
Summary:        Tool to inspect RP2040 binaries
License:        BSD-3-Clause
Group:          Development/Tools/Other
URL:            https://github.com/raspberrypi/picotool
Source0:        https://github.com/raspberrypi/picotool/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        https://github.com/raspberrypi/pico-sdk/archive/%{sdk_version}.tar.gz#/pico-sdk-%{sdk_version}.tar.gz
BuildRequires:  cmake >= 3.12
BuildRequires:  gcc-c++
BuildRequires:  libusb-1_0-devel

%description
Picotool is a tool for inspecting RP2040 binaries, and interacting with RP2040 devices when they are in BOOTSEL mode.

%prep
%autosetup -a 1
#Revert https://github.com/raspberrypi/picotool/commit/6ad9c23
sed -i 's#set(INSTALL_CONFIGDIR lib/cmake/picotool)#set(INSTALL_CONFIGDIR ${CMAKE_INSTALL_LIBDIR}/cmake/picotool)#' CMakeLists.txt

%build
%cmake -DPICO_SDK_PATH="../pico-sdk-%{sdk_version}"
%cmake_build

%install
%cmake_install

%files
%doc README.md
%license LICENSE.TXT
%{_bindir}/picotool
%{_libdir}/cmake/picotool
%{_datadir}/picotool

%changelog
* Tue Mar 11 2025 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Fix cmake installation path on 64-bit architectures
* Tue Mar 11 2025 Dominik Heidler <dheidler@suse.de>
- Update to 2.1.1
  * Sped up the coprodis command which was very slow for large files on some platforms
  * Sped up the info command by caching data read from the device
- Update to 2.1.0
  * Added partition table; and otp permissions, whitelabel, contents and settings JSON schemas
  * Moved example json files into json folder, with schemas in json/schemas
  * All commands now require 0x before hexadecimal family IDs
* Tue Oct 29 2024 Michal Suchanek <msuchanek@suse.de>
- Update to 2.0.0
  * Offset now valid for ELF and UF2 files on RP2350
  * Displays info on the embedded block for RP2350
  * Displays information for binaries in partitions too
  * Added -cpu option on RP2350 to switch archtectures
  * Added diagnostic partition option on RP2350
* Tue Jul 25 2023 Andrea Manzini <andrea.manzini@suse.com>
- update to 1.1.2:
  * Small release with one bug fix to allow specifying 0 for --bus, and some minor documentation edits.
- bump SDK to latest 1.5.1 to support newer boards
* Wed Feb 15 2023 Dirk Müller <dmueller@suse.com>
- update to 1.1.1:
  * Add --update option to `load` command to skip unchanged flash
    sectors (speed improvement).
  * A number of minor bug fixes and documentation improvements.
  * Support non contiguous flash ELF/UF2 which were written
    incorrectly before (and yet still passed verify due to
    another bug).
* Fri Dec 10 2021 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update to 1.1.0:
  * Add version command
  * Fix parsing of ELF where the program header does not directly follow the file header
  * Add install-ability via `cmake install`
  * Incorporate slightly modified Win32 libusb find helpers
  * Add ability to access device using stdio_usb
  * Add -n option to load to avoid overwriting existing program
  * Add -f/-F option to force reset a cooperative RP2040 board that isnt in BOOTSEL mode
  * Add a sudo suggestion when can't connect on linux/macos
- Drop upstreamed patches:
  * picotool-ce76970.patch
  * picotool-gh30.patch
- Update SDK version to 1.3.0
* Wed Oct 20 2021 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Backport patch to fix installation path:
  * picotool-ce76970.patch
* Fri Jul 23 2021 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update SDK version to 1.2.0
* Thu Jun  3 2021 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Add patch to fix build with GCC11:
  * picotool-gh30.patch
* Sun May 23 2021 Mustafa Çalışkan <musfay@protonmail.com>
- Upstream started to tag versions so drop _service and change
  source to upstream tarball
* Sat May  1 2021 Mustafa Çalışkan <musfay@protonmail.com>
- Update to version 0.0~git20210424.a49dc0b:
  * Fix detection of unknown flash-size when saving
  * Add boot2 to build information
  * Various typos fixed
* Thu Apr  8 2021 Mustafa Çalışkan <musfay@protonmail.com>
- Update SDK version to 1.1.2
* Sun Apr  4 2021 Mustafa Çalışkan <musfay@protonmail.com>
- Update SDK version to 1.1.1
* Mon Mar  8 2021 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update to version 0.0~git20210305.21d5eb9 with SDK 1.1.0
- Add %%license
* Fri Feb 19 2021 Mustafa Çalışkan <musfay@protonmail.com>
- Update to version 0.0~git20210130.20eee8c with SDK 1.0.1
* Fri Jan 29 2021 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Initial version 0.0~git20210129.f0328c2 with SDK 1.0.0
